uni_links library

Properties

linkStream → Stream<String?>
A broadcast stream for receiving incoming link change events.
no setter
uriLinkStream → Stream<Uri?>
A convenience transformation of the linkStream to a Stream<Uri>.
latefinal

Functions

Returns a Future, which completes to the initially stored link, which may be null.
getInitialUri() → Future<Uri?>
A convenience method that returns the initially stored link as a new Uri object.